@@ -1,10 +1,6 @@
 package Git::Class::Worktree;
 
-use Any::Moose; with qw/
-  Git::Class::Role::Execute
-  Git::Class::Role::Cwd
-/;
-use MRO::Compat;
+use Any::Moose; with 'Git::Class::Role::Execute';
 use File::Spec;
 
 has '_path' => (
@@ -15,7 +11,7 @@ has '_path' => (
   trigger  => sub {
     my ($self, $path) = @_;
     $self->{path} = File::Spec->rel2abs($path);
-    chdir $path;
+    $self->_execute( chdir => $path );
   },
 );
 
@@ -25,8 +21,7 @@ has '_cmd' => (
   init_arg   => 'cmd',
   builder    => '_build__cmd',
   handles    => [qw(
-    git
-    add branch checkout commit config diff fetch init log move 
+    add branch checkout commit diff fetch init log move 
     push pull rebase reset remove show status tag
   )],
 );
@@ -37,16 +32,9 @@ sub _build__cmd {
   return Git::Class::Cmd->new(
     die_on_error => $self->_die_on_error,
     verbose      => $self->is_verbose,
-    cwd          => $self->_path,
   );
 }
 
-sub DEMOLISH {
-  my $self = shift;
-
-  chdir $self->_cwd if $self->_cwd;
-}
-
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -68,17 +56,9 @@ Git::Class::Worktree
   $work->add('.');
   $work->commit;
 
-  $work->git('ls-files'); # can run an arbitrary command
-
 =head1 DESCRIPTION
 
-This is another (experimental) interface to C<git> executable for convenience. Note that this will change the current directory to the path you specify when you create an object, and as of 0.03, it'll take you back to the previous current directory when you demolish the object.
-
-=head1 INTERNAL METHODS
-
-=head2 BUILDARGS
-
-=head2 DEMOLISH
+This is another (experimental) interface to C<git> executable for convenience. Note that this will change the current directory to the path you specify when you create an object.
 
 =head1 AUTHOR
 
